'===============================================================================
'
' RamPage2 General definitions :
'
' NOTE: These definitions can be replaced by the correct platform definitions
'       for the platform on which the RamPage2 board is installed. These default 
'       pin definitions are appropriate for both the Propeller Platform and the
'       Parallax QuickStart board.
'
'===============================================================================
'
KBD_PIN    = -1                 ' BASE PIN (RamPage2) - No Keyboard
MOUSE_PIN  = -1                 ' BASE PIN (RamPage2) - No Mouse
TV_PIN     = -1                 ' BASE PIN (RamPage2) - No TV output
VGA_PIN    = -1                 ' BASE PIN (RamPage2) - No VGA output 
SOUND_PIN  = -1                 ' PIN (RamPage2) - No Sound
NES_CL_PIN = -1                 ' PIN (RamPage2) - No Gamepad
NES_LT_PIN = -1                 ' PIN (RamPage2) - No Gamepad
NES_D1_PIN = -1                 ' PIN (RamPage2) - No Gamepad
NES_D2_PIN = -1                 ' PIN (RamPage2) - No Gamepad
SD_CD_PIN  = 11                 ' PIN (RamPage2)
SD_DO_PIN  = 12                 ' PIN (RamPage2)
SD_CLK_PIN = 13                 ' PIN (RamPage2)
SD_DI_PIN  = 14                 ' PIN (RamPage2)
SD_CS_PIN  = 15                 ' PIN (RamPage2)
I2C_PIN    = 28                 ' I2C Boot EEPROM SCL Pin
I2C_DEV    = $A0                ' I2C Boot EEPROM Device Address
SI_PIN     = 31                 ' PIN (RamPage2)
SO_PIN     = 30                 ' PIN (RamPage2)
'
DEBUG_PIN  = SD_CD_PIN          ' Debug LED (RamPage2) - use LED connected to CD pin
'
' RamPage2 Clock Definitions:
'
CLOCKMODE = xtal1 + pll16x      ' (RamPage2)
XTALFREQ  = 5_000_000           ' (RamPage2)
CLOCKFREQ = 80_000_000          ' (RamPage2) Nominal clock frequency (required by some drivers)
'
' RamPage2 InterProp comms definitions:
'
DEFAULT_CPU   = 0               ' RamPage2 has only one CPU
SIO_BAUD      = 115200          ' Baud rate to use for all interprop comms                 
SIO_LOAD_MODE = %0000           ' SIO Mode used by targets during load (loader uses SIO_COMM_MODE)
SIO_COMM_MODE = %0000           ' SIO Mode used by clients and servers for InteProp Comms

TX_PIN     = -1                 ' RamPage2 has only one CPU
RX_PIN     = -1                 ' RamPage2 has only one CPU
'
' RamPage2 Payload pins (SI/SO pins)
'
PAYLOAD_RXPIN = SI_PIN          ' Rx pin to use for Payload comms
PAYLOAD_TXPIN = SO_PIN          ' Tx pin to use for Payload comms
'
' RamPage2 BlackCat debug pins (SI/SO pins)
'
BLACKCAT_RXPIN = SI_PIN         ' Rx pin to use for BlackCat comms
BLACKCAT_TXPIN = SO_PIN         ' Tx pin to use for BlackCat comms
BLACKCAT_MODE  = %0000          ' SIO mode to use for BlackCat comms
'
' Cog Allocation. The value LAST_COG specifies the last cog that will 
' be restarted during the load process. It should be set to one less than
' the cog used for the CogStore. If the Cache is in use it will always be
' started in Cog 7, and if CogStore is in use it will always be started in
' the next lower cog. Set this value lower still to reserve one or more cogs 
' for other purposes. Note that it is still the users responsibility to 
' ensure that the combination of loaded drivers and plugins does not 
' exceed this value. Note also that the CogStore cog can be used by an
' application - it is not restarted during the load process (otherwise 
' its values would be lost) - but it is restarted before any user 
' plugins are loaded. 
'
#ifdef CACHED

CACHE_COG    = 7                ' XMM Cache driver will use this cog
STORE_COG    = 6                ' Catalina CogStore will use this cog
LAST_COG     = 5                ' Last cog to be restarted is 5

'
' The following constant determines the number of longs used in the
' cache cog index - it can be reduced (e.g. to 6) if the XMM API 
' is so large it needs more space even in the cache cog (e.g. for 
' QUAD FLASH boards):
'
CACHE_INDEX_LOG2 = 7            ' log2 of entries in cache index

#else

CACHE_COG    = -1               ' XMM Cache driver not loaded
STORE_COG    = 7                ' Catalina CogStore will use this cog
LAST_COG     = 6                ' Last cog to be restarted is 6

#endif 
'
'===============================================================================
'
' RamPage2 SPI FLASH & SRAM Pins
'
SIO0_PIN  = 0                   ' BASE PIN (RamPage2) - See also SHIFT_DATA (below)
SIO1_PIN  = SIO0_PIN + 1
SIO2_PIN  = SIO1_PIN + 1
SIO3_PIN  = SIO2_PIN + 1
SIO4_PIN  = SIO3_PIN + 1
SIO5_PIN  = SIO4_PIN + 1
SIO6_PIN  = SIO5_PIN + 1
SIO7_PIN  = SIO6_PIN + 1
'
MOSI1_PIN = SIO0_PIN            ' Output from Prop to chip 1 (SRAM or FLASH)
MISO1_PIN = SIO1_PIN            ' Input from chip 1 (SRAM or FLASH) to Prop
MOSI2_PIN = SIO4_PIN            ' Output from Prop to chip 2 (SRAM or FLASH)
MISO2_PIN = SIO5_PIN            ' Input from chip 2 (SRAM or FLASH) to Prop 
'
SIO_CLK_PIN   = 8
SIO_FLASH_PIN = 9
SIO_SRAM_PIN  = 10
'
' Since Homespun has no general "#if" capability, we cannot tell from the
' PIN numbers defined above whether or not we have to shift bits left to 
' make the data bits align with the pins SIO0_PIN .. SIO7_PIN - so to save 
' unnecessary instructions, we explicitly define here whether or not we need 
' to shift data to align with the pins:
'
' Define this if bits have to be shifted for I/O (i.e. SIO0_PIN pin > 0) :
'
'#define SHIFT_DATA
'
' XMM Base Address. Catalina currently requires one contiguous block 
' of XMM RAM - Note that this is the internal hardware address, not 
' the address the Catalina XMM Kernel uses:
'
XMM_BASE_ADDRESS = $0000_0000   ' XMM adddressing from 0
'
' XMM RW & RO Base Addresses - Note that these are the addresses used
' by the Catalina XMM Kernel - they typically start AFTER the last
' Hub address:
'
XMM_RW_BASE_ADDRESS = $0000_8000 ' Read-Write Base address
XMM_RO_BASE_ADDRESS = $0004_8000 ' Read-Only Base address
'
' XMM RW & RO Sizes (in bytes):
'
XMM_RW_SIZE = $0002_0000         ' Read-Write Size
XMM_RO_SIZE = $0040_0000         ' Read-Only Size

'===============================================================================

